@@ -125,7 +125,7 @@ class NmfModel:
         model.set_n_bootstrap(self._n_bootstrap)
         return model
 
-    def set_sparsity(self, sparsity):
+    def set_sparsity(self, sparsity: object):
         sp = self._sparsity
         self._sparsity = sparsity
         if sp != sparsity:
@@ -665,25 +665,26 @@ def generate_scree_plot(mat: Union[np.ndarray, pd.DataFrame],
         line.loc[ncomp, "Avg_relative_entropy"] = nmfmodel.get_avg_diag_entropies(nbins=5,
                                                                                   size_weighted=True,
                                                                                   relative=True).iloc[0, 0]
-    df_scree_plot = pd.concat([df_scree_plot, line], axis=0)
+        df_scree_plot = pd.concat([df_scree_plot, line], axis=0)
     return df_scree_plot
 
 
 def add_miniscree_plots_from_scree_plot(df_examples: pd.DataFrame,
                                         scree_plot: pd.DataFrame,
                                         known_ncomp: int,
-                                        window_size: int = 6):
+                                        window_size: int = 6,
+                                        dropna: bool = True):
 
     nb_examples, _ = df_examples.shape
+    duplicated_examples = utl.duplicate_data_wfold(df=scree_plot, window=window_size)
+    if dropna:
+        duplicated_examples.dropna(axis='index', how='any', inplace=True)
     for ncomp in scree_plot.index:
-        if ncomp + window_size - 1 <= scree_plot.index[-1]:
-            example = pd.DataFrame(index=[nb_examples], columns=scree_plot.columns)
-            position = 0 if known_ncomp <= ncomp else window_size-1 if known_ncomp >= ncomp + window_size - 1 \
+        position = 0 if known_ncomp <= ncomp else window_size-1 if known_ncomp >= ncomp + window_size - 1 \
                 else known_ncomp - ncomp
-            example.loc[nb_examples, :] = scree_plot.loc[ncomp, :]
-            example.loc[nb_examples, "Position"] = position
-            nb_examples += 1
-            df_examples = pd.concat([df_examples, example], axis=0)
+
+        duplicated_examples.loc[ncomp, "Position"] = position
+    df_examples = pd.concat([df_examples, duplicated_examples], axis=0)
     return df_examples
 
 
