@@ -225,8 +225,58 @@ if __name__ == "__main__":
 
         imp_tester.output_results(out_data_path)
 
-    if os.getenv("imp_do_ecodata_gans", "False").lower() == "true":
+    if os.getenv("imp_do_random_block_matrices", "False").lower() == "true":
+        # Expérience pour prouver que l'imputation de valeurs via SNMF
+        # donne les meilleurs résultats quand on connait le nombre exact de composants
+        # nb_clusters = np.random.randint(low=5, high=40)
+        nb_clusters = 12
+        min_corr = np.random.uniform(low=0.75, high=0.95)
+        min_corr = 0.90
+        max_corr = np.random.uniform(low=0.05, high=0.25)
+        max_corr = 0.10
+        h_avg_csize = np.random.randint(low=10, high=20)
+        h_avg_csize = 20
+        w_avg_csize = np.random.randint(low=10, high=100)
+        w_avg_csize = 40
+        rnd_norms = False
+        # eps = np.random.uniform(low=0.0, high=0.25)
+        eps = 0.0
+        generated_M = rng.generate_nmf_reconstruction(n_comp=nb_clusters,
+                                                      min_intra_corr=min_corr,
+                                                      max_inter_corr=max_corr,
+                                                      h_avg_clust_size=h_avg_csize,
+                                                      w_avg_clust_size=w_avg_csize,
+                                                      epsilon=eps,
+                                                      random_norms=rnd_norms)
+        imp_nmf_proxy = imp.Imputer(method="nmf.proxy",
+                                    params={"ncomp": 3,
+                                            "nblocks": 1,
+                                            "nfill_iters": 0})
 
+        imp_nmf_proxy_pgrad = imp.Imputer(method="nmf.proxy",
+                                          params={"ncomp": 3,
+                                                  "nblocks": 1,
+                                                  "use_hals": False,
+                                                  "nfill_iters": 0})
+
+        imputers = [[imp_nmf_proxy, None],
+                    [imp_nmf_proxy_pgrad, None]]
+        imp_name = "RandomBlockMatrices_2"
+        imp_tester = imp.ImputerTester(mat=generated_M, name=f"{imp_name}_nc{nb_clusters}",
+                                       imputer=imp_nmf_proxy, ref_clst=None,
+                                       clst=None, err_func="MSE")
+        for imp in imputers:
+            for nc in range(5, 20):
+                imputer = imp[0]
+                imputer.set_ncomp(nc)
+                imp_tester.set_imputer(imputer)
+                # imp_tester.run([0.05, 0.10, 0.25, 0.4], ntrials=20)
+                imp_tester.run([0.05], ntrials=1)
+
+        imp_tester.output_results(out_data_path)
+
+    if os.getenv("imp_do_ecodata_gans", "False").lower() == "true":
+        # expérience où l'on soumet les résultats de l'imputation à un GAN
         # localisation du modèle GAN
         path_models = Path('/media/SERVEUR/production/research_and_development/AdFactory/Models/')
         # model_name = '15_09_21_25000_epochs'
@@ -244,7 +294,7 @@ if __name__ == "__main__":
         eco_data_path = Path('/media/SERVEUR/production/research_and_development/AdFactory/Data/test_critic_full')
         eco_df = pd.DataFrame(index=range(nb_obs),
                               columns=eco_feat_list,
-                               data=np.random.normal(size=[nb_obs, nb_eco_feat]))
+                              data=np.random.normal(size=[nb_obs, nb_eco_feat]))
 
         ncomp_eco = 6
         p_step = 0.05
