@@ -244,26 +244,27 @@ def generate_nmf_reconstruction(n_comp: int,
                                 w_avg_clust_size: int,
                                 epsilon: float,
                                 random_norms: bool = True):
-    cl_vects_H = utl.generate_clusterized_vectors(veclen=n_comp,
+
+    cl_vects_h = utl.generate_clusterized_vectors(veclen=n_comp,
                                                   nclusters=n_comp,
                                                   nbvect=n_comp * h_avg_clust_size,
                                                   clusterminsize=int(h_avg_clust_size/2),
                                                   max_inter_corr=max_inter_corr,
                                                   min_intra_corr=min_intra_corr,
                                                   random_norms=random_norms)
-    cl_vects_W = utl.generate_clusterized_vectors(veclen=nb_clusters,
-                                                  nclusters=nb_clusters,
-                                                  nbvect=nb_clusters * w_avg_clust_size,
+    cl_vects_w = utl.generate_clusterized_vectors(veclen=n_comp,
+                                                  nclusters=n_comp,
+                                                  nbvect=n_comp * w_avg_clust_size,
                                                   clusterminsize=int(w_avg_clust_size/2),
                                                   max_inter_corr=max_inter_corr,
                                                   min_intra_corr=min_intra_corr,
                                                   random_norms=random_norms)
-    cl_vects_W = cl_vects_W.T
-    cl_vects_M = cl_vects_W @ cl_vects_H
-    noise = np.random.normal(loc=0.0, scale=epsilon, size=cl_vects_M.shape)
-    cl_vects_M *= 1 + noise
-    cl_vects_M = np.maximum(cl_vects_M, 0)
-    return cl_vects_M
+    cl_vects_w = cl_vects_w.T
+    cl_vects_m = cl_vects_w @ cl_vects_h
+    noise = np.random.normal(loc=0.0, scale=epsilon, size=cl_vects_m.shape)
+    cl_vects_m *= 1 + noise
+    cl_vects_m = np.maximum(cl_vects_m, 0)
+    return cl_vects_m
 
 
 if __name__ == "__main__":
@@ -276,7 +277,7 @@ if __name__ == "__main__":
     data_path = imputation_paper_path / os.getenv("data_subpath")
     res_path = imputation_paper_path / os.getenv("results_subpath")
 
-    train_f_name = f"mini_scree_plots.csv"
+    train_f_name = f"wfold_scree_plots.csv"
 
     if os.path.isfile(res_path / "random_nmf" / train_f_name):
         df_mini_scree_plots = pd.read_csv(res_path / "random_nmf" / train_f_name)
@@ -284,27 +285,26 @@ if __name__ == "__main__":
         df_mini_scree_plots = pd.DataFrame(index=[], columns=[])
 
     # train_f_name = "foo_scree.csv"
-    random_norms = True
-    for itrial in range(20):
-        nb_clusters = np.random.randint(low=5, high=50)
-        min_corr = np.random.uniform(low=0.80, high=0.95)
-        max_corr = np.random.uniform(low=0.05, high=0.20)
+    rand_norms = True
+    for itrial in range(200):
+        nb_clusters = np.random.randint(low=5, high=40)
+        min_corr = np.random.uniform(low=0.75, high=0.95)
+        max_corr = np.random.uniform(low=0.05, high=0.25)
         h_avg_csize = np.random.randint(low=10, high=20)
         w_avg_csize = np.random.randint(low=10, high=100)
-        # eps = np.random.uniform(low=0.05, high=0.25)
-        eps = 0.0
+        eps = np.random.uniform(low=0.0, high=0.25)
         generated_M = generate_nmf_reconstruction(n_comp=nb_clusters,
                                                   min_intra_corr=min_corr,
                                                   max_inter_corr=max_corr,
                                                   h_avg_clust_size=h_avg_csize,
                                                   w_avg_clust_size=w_avg_csize,
                                                   epsilon=eps,
-                                                  random_norms=random_norms)
-        rnstr = "RandNorms" if random_norms else "ConstNorms"
-        generated_M.to_csv(res_path / "random_nmf" / f"M_nc{nb_clusters}_corrmin{round(min_corr,2)}_"
+                                                  random_norms=rand_norms)
+        rnstr = "RandNorms" if rand_norms else "ConstNorms"
+        generated_M.to_csv(res_path / "random_nmf" / f"M_t{itrial}_nc{nb_clusters}_corrmin{round(min_corr,2)}_"
                                        f"corrmax{round(max_corr,2)}_noise{round(eps,2)}_{rnstr}.csv",
                            float_format="%.4f")
-        df_scree_plot = nmf.generate_scree_plot(generated_M, ncmin=5, ncmax=40)
+        df_scree_plot = nmf.generate_scree_plot(generated_M, ncmin=3, ncmax=45)
         df_mini_scree_plots = nmf.add_miniscree_plots_from_scree_plot(df_mini_scree_plots, df_scree_plot, nb_clusters)
         df_mini_scree_plots.to_csv(res_path / "random_nmf" / train_f_name)
 
